import type { MouseEvent, HTMLProps } from "react";
import { ValueOf, PropsWithSpread } from "../../types";
export declare enum Label {
    Dismiss = "Dismiss"
}
export declare const ChipType: {
    readonly CAUTION: "caution";
    readonly INFORMATION: "information";
    readonly NEGATIVE: "negative";
    readonly POSITIVE: "positive";
};
export declare type Props = PropsWithSpread<{
    /**
     * The appearance of the chip.
     */
    appearance?: ValueOf<typeof ChipType>;
    /**
     * The lead for the chip.
     */
    lead?: string;
    /**
     * Function for handling chip div click event.
     */
    onClick?: (event: MouseEvent<HTMLButtonElement> | {
        lead: string;
        value: string;
    }) => void;
    /**
     * Function for handling dismissing a chip.
     */
    onDismiss?: () => void;
    /**
     * Whether the chip is selected.
     */
    selected?: boolean;
    /**
     * A substring to emphasise if it is part of the chip's value,
     * e.g. "sit" => poSITive
     */
    subString?: string;
    /**
     * Whether to wrap the value in quotation marks.
     */
    quoteValue?: boolean;
    /**
     * The value of the chip.
     */
    value: string;
}, HTMLProps<HTMLButtonElement>>;
declare const Chip: ({ appearance, lead, onClick, onDismiss, quoteValue, selected, subString, value, ...props }: Props) => JSX.Element;
export default Chip;
