import { ReactNode, HTMLProps } from "react";
import type { GenerateLink, NavItem, LogoProps } from "./types";
import { PropsWithSpread, SubComponentProps } from "../../types";
import { SearchBoxProps } from "../SearchBox";
import { Theme } from "../../enums";
export declare type Props = PropsWithSpread<{
    /**
     * By default the header is constrained to the width of the grid. Use this
     * option to make the header take the full width of the page.
     */
    fullWidth?: boolean;
    /**
     * This function can be used to generate link elements when you don't want to
     * use a standard HTML anchor.
     */
    generateLink?: GenerateLink | null;
    /**
     * The main navigation items that appear on the left hand side next to the logo.
     */
    items?: NavItem[] | null;
    /**
     * Additional navigation items that appear on the right hand side of the
     * navigation banner.
     */
    itemsRight?: NavItem[] | null;
    /**
     * Additional props to be applied to the nav element that wraps the main
     * navigation items on the left hand side.
     */
    leftNavProps?: HTMLProps<HTMLUListElement> | null;
    /**
     * The logo can be defined either by providing props for the standard logo
     * or the full logo markup when a custom logo is needed.
     */
    logo: LogoProps | ReactNode;
    /**
     * Additional props to be applied to the nav element that wraps the
     * left and right nav items.
     */
    navProps?: HTMLProps<HTMLElement> | null;
    /**
     * Additional props to be applied to the nav element that wraps the
     * navigation items on the right hand side.
     */
    rightNavProps?: HTMLProps<HTMLUListElement> | null;
    /**
     * Props to pass to the SearchBox component. When these props are provided the
     * search box will appear.
     */
    searchProps?: SubComponentProps<SearchBoxProps> | null;
    /**
     * The header theme. When this is not provided the header will use the default
     * theme defined in the Vanilla settings.
     */
    theme?: Theme | null;
}, HTMLProps<HTMLElement>>;
declare const Navigation: ({ fullWidth, generateLink, items, itemsRight, leftNavProps, logo, navProps, rightNavProps, searchProps, theme, ...headerProps }: Props) => JSX.Element;
export default Navigation;
