import type { HTMLProps, ElementType, ReactNode, ComponentType } from "react";
import type { ClassName } from "../../types";
export declare type TabLink<P = null> = {
    /**
     * Whether the tab link should have active styling.
     */
    active?: boolean;
    /**
     * Optional classes applied to the link element.
     */
    className?: ClassName;
    /**
     * Optional component to be used instead of the default "a" element.
     */
    component?: ElementType | ComponentType<P>;
    /**
     * Label to be displayed inside the tab link.
     */
    label: ReactNode;
    /**
     * Optional classes applied to the "li" element.
     */
    listItemClassName?: string;
} & (HTMLProps<HTMLElement> | P);
export declare type Props<P = null> = {
    /**
     * Optional classes applied to the parent "nav" element.
     */
    className?: ClassName;
    /**
     * An array of tab link objects.
     */
    links: TabLink<P>[];
    /**
     * Optional classes applied to the "ul" element.
     */
    listClassName?: string;
};
declare const Tabs: <P>({ className, links, listClassName, }: Props<P>) => JSX.Element;
export default Tabs;
