/**
 * A hook that handles pagination.
 * @param data - The data array to paginate.
 * @param {Object} options
 * @param {number} [options.itemsPerPage] - Number of items per page. Returns all items if no value has been provided.
 * @param {number} [options.initialPage=1] - Initial page number. Defaults to 1.
 * @param {boolean} [options.autoResetPage=false] - Whether to reset the page number to 1 when the data changes.
 */
export declare function usePagination<D, I = number | null>(data: Array<D>, options?: {
    itemsPerPage: I;
    initialPage?: number;
    autoResetPage?: boolean;
}): {
    pageData: Array<D>;
    currentPage: number;
    paginate: (pageNumber: number) => void;
    itemsPerPage: I;
    totalItems: number;
};
