/**
 * This type should be used for all className props in order to ensure
 * consistency across components.
 */
export declare type ClassName = string | null;
/**
 * The allowable heading levels.
 */
export declare type Headings = "h1" | "h2" | "h3" | "h4" | "h5" | "h6";
/**
 * This type can be used when defining props that also spread the props of
 * something else. It ensures that the defined component props are never
 * overwritten by the spread props.
 */
export declare type PropsWithSpread<P, H> = P & Omit<H, keyof P>;
/**
 * The allowable sort directions e.g. for a sortable table.
 */
export declare type SortDirection = "none" | "ascending" | "descending";
/**
 * This type can be used when passing props to a sub component. It makes all
 * component props optional.
 */
export declare type SubComponentProps<P> = Partial<P> & {
    [prop: string]: unknown;
};
/**
 * This type is simply an alias for the 'any' type and should be used sparingly,
 * if at all.
 */
export declare type TSFixMe = any;
/**
 * This type allows for converting an object const into an enum-like construct,
 * e.g. value: ValueOf<typeof EnumLike> will only allow value to be a value
 * defined in EnumLike.
 */
export declare type ValueOf<T> = T[keyof T];
